@@ -17,6 +17,9 @@
 #' rbind them.
 #' @param crs coordinate reference system in numeric format from
 #' http://spatialreference.org/ to transform/project spatial data using sf::st_transform
+#' @param under "Character"; "after" when you stored your pollutant x as 'X_'
+#' "before" when '_X' and "none" for merging directly the files.
+#' @param as_list "Logical"; for returning the results as list or not.
 #' @return 'Spatial feature' of lines or a dataframe of emissions
 #' @importFrom data.table rbindlist .SD
 #' @importFrom sf st_set_geometry st_sf st_geometry st_as_sf st_transform
@@ -30,24 +33,42 @@ emis_merge <- function (pol = "CO",
                         streets = T,
                         net,
                         path = "emi",
-                        crs){
+                        crs,
+                        under = "after",
+                        as_list = FALSE){
   x <- list.files(path = path,
                   pattern = what,
                   all.files = T,
                   full.names = T,
                   recursive = T)
-  x <- x[grep(pattern = paste0(pol, "_"), x = x)]
+  if(under == "after"){
+    x <- x[grep(pattern = paste0(pol, "_"), x = x)]
+  } else if (under == "before"){
+    x <- x[grep(pattern = paste0("_", pol), x = x)]
+  } else {
+    x <-  x[grep(pattern = pol, x = x)]
+  }
+
+nx <- gsub(pattern = paste0(getwd(), '/', path),
+           replacement = "", x = x)
+kk <- substr(x = nx, start = 11, stop = 50)
+kk <- gsub(pattern = "/", replacement = "", kk)
+kk <- gsub(pattern = ".rds", replacement = "", kk)
+nx <- kk
 
   cat("\nReading emissions from:\n")
   print(x)
   x_rds <- lapply(x, readRDS)
+  names(x_rds) <- nx
+  if(as_list) return(x_rds)
 
-    nombres <- names(x_rds[[1]])
+  nombres <- names(x_rds[[1]])
 
-    if(streets){
+  if(streets){
     for (i in 1:length(x_rds)){
       x_rds[[i]]$id <- 1:nrow(x_rds[[i]])
     }
+
     x_st <- data.table::rbindlist(x_rds)
     x_st <- as.data.frame(x_st[, lapply(.SD, sum, na.rm=TRUE),
                                by = "id",
@@ -58,7 +79,7 @@ emis_merge <- function (pol = "CO",
     net <- sf::st_as_sf(net)
     if(!missing(crs)) {
       net <- sf::st_transform(net, crs)
-      }
+    }
     netx <- st_sf(x_st, geometry = sf::st_geometry(net))
     return(netx)
   } else{
